summaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-reassoc.c
diff options
context:
space:
mode:
authorrevitale <revitale@138bc75d-0d04-0410-961f-82ee72b054a4>2007-09-04 12:11:11 +0000
committerrevitale <revitale@138bc75d-0d04-0410-961f-82ee72b054a4>2007-09-04 12:11:11 +0000
commit49d060d774950223dc4acbf852f21652095db37a (patch)
tree67cecf461cc930540853bd8eb0d4f19b3b21b0ce /gcc/tree-ssa-reassoc.c
parent4076554cd7837c65c54a7b0508ef64fb3271a369 (diff)
downloadgcc-49d060d774950223dc4acbf852f21652095db37a.tar.gz
Add new fp flags: -fassociative-math and -freciprocal-math
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@128075 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/tree-ssa-reassoc.c')
-rw-r--r--gcc/tree-ssa-reassoc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/tree-ssa-reassoc.c b/gcc/tree-ssa-reassoc.c
index 87db02f3273..f75437d0522 100644
--- a/gcc/tree-ssa-reassoc.c
+++ b/gcc/tree-ssa-reassoc.c
@@ -1244,14 +1244,14 @@ break_up_subtract_bb (basic_block bb)
tree rhs = GIMPLE_STMT_OPERAND (stmt, 1);
TREE_VISITED (stmt) = 0;
/* If unsafe math optimizations we can do reassociation for
non-integral types. Or, we can do reassociation for
non-saturating fixed-point types. */
if ((!INTEGRAL_TYPE_P (TREE_TYPE (lhs))
|| !INTEGRAL_TYPE_P (TREE_TYPE (rhs)))
&& (!SCALAR_FLOAT_TYPE_P (TREE_TYPE (rhs))
|| !SCALAR_FLOAT_TYPE_P (TREE_TYPE(lhs))
- || !flag_unsafe_math_optimizations)
+ || !flag_associative_math)
&& (!NON_SAT_FIXED_POINT_TYPE_P (TREE_TYPE (rhs))
|| !NON_SAT_FIXED_POINT_TYPE_P (TREE_TYPE(lhs))))
continue;
@@ -1294,14 +1294,14 @@ reassociate_bb (basic_block bb)
if (TREE_VISITED (stmt))
continue;
/* If unsafe math optimizations we can do reassociation for
non-integral types. Or, we can do reassociation for
non-saturating fixed-point types. */
if ((!INTEGRAL_TYPE_P (TREE_TYPE (lhs))
|| !INTEGRAL_TYPE_P (TREE_TYPE (rhs)))
&& (!SCALAR_FLOAT_TYPE_P (TREE_TYPE (rhs))
|| !SCALAR_FLOAT_TYPE_P (TREE_TYPE(lhs))
- || !flag_unsafe_math_optimizations)
+ || !flag_associative_math)
&& (!NON_SAT_FIXED_POINT_TYPE_P (TREE_TYPE (rhs))
|| !NON_SAT_FIXED_POINT_TYPE_P (TREE_TYPE(lhs))))
continue;
@@ -1244,14 +1244,14 @@ break_up_subtract_bb (basic_block bb)
tree rhs = GIMPLE_STMT_OPERAND (stmt, 1);
TREE_VISITED (stmt) = 0;
- /* If unsafe math optimizations we can do reassociation for
+ /* If associative-math we can do reassociation for
non-integral types. Or, we can do reassociation for
non-saturating fixed-point types. */
@@ -1294,14 +1294,14 @@ reassociate_bb (basic_block bb)
if (TREE_VISITED (stmt))
continue;
- /* If unsafe math optimizations we can do reassociation for
+ /* If associative-math we can do reassociation for
non-integral types. Or, we can do reassociation for
non-saturating fixed-point types. */